@@ -44,6 +44,10 @@ public:
   void startRepeating(
     PIRKeyName name);
 
+  void startRepeating(
+    PIRKeyName name,
+    unsigned int keysetID);
+
   void stopRepeating();
 
   void selectPanel(
@@ -75,6 +79,14 @@ public:
   void useMainPanel();
   void useAltMainPanel();
 
+  QString getCurrentMake();
+  QString getCurrentName();
+
+  unsigned int getCurrentKeyset()
+  {
+    return currentKeyset;
+  }
+
 signals:
   void buttonPressed(
     unsigned int keysetID,
